==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/WebSelectItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebDropdownItemDescriptionMetadata } from "./WebDropdownItemDescriptionMetadata";
import { WebSelectItemDescription } from "./WebSelectItemDescription";
/**
 * @hidden
 */
export let WebSelectItemDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSelectItemDescriptionMetadata extends Base {
        static b(a) {
            if (WebSelectItemDescriptionMetadata.a == null) {
                WebSelectItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSelectItemDescriptionMetadata.c(WebSelectItemDescriptionMetadata.a);
            }
            if (a.k(WebSelectItemDescriptionMetadata.a)) {
                return;
            }
            a.ab(WebSelectItemDescriptionMetadata.a);
        }
        static c(a) {
            WebDropdownItemDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:SelectItem");
            a.item("__tagNameWC", "String:igc-select-item");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
            a.item("TextContent", "String");
        }
        static d(a) {
            WebSelectItemDescriptionMetadata.b(a);
            a.ad("WebSelectItem", () => new WebSelectItemDescription());
            a.ac("WebSelectItem", WebSelectItemDescriptionMetadata.a);
        }
    }
    WebSelectItemDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSelectItemDescriptionMetadata, 'WebSelectItemDescriptionMetadata');
    WebSelectItemDescriptionMetadata.a = null;
    return WebSelectItemDescriptionMetadata;
})();

==> igniteui-react-core-18.7.5-beta.2.tgz: package/esm2015/lib/WebSelectItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebBaseOptionLikeDescriptionMetadata } from "./WebBaseOptionLikeDescriptionMetadata";
import { WebSelectItemDescription } from "./WebSelectItemDescription";
/**
 * @hidden
 */
export let WebSelectItemDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebSelectItemDescriptionMetadata extends Base {
        static b(a) {
            if (WebSelectItemDescriptionMetadata.a == null) {
                WebSelectItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebSelectItemDescriptionMetadata.c(WebSelectItemDescriptionMetadata.a);
            }
            if (a.k(WebSelectItemDescriptionMetadata.a)) {
                return;
            }
            a.ac(WebSelectItemDescriptionMetadata.a);
        }
        static c(a) {
            WebBaseOptionLikeDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:SelectItem");
            a.item("__tagNameWC", "String:igc-select-item");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents");
        }
        static d(a) {
            WebSelectItemDescriptionMetadata.b(a);
            a.ae("WebSelectItem", () => new WebSelectItemDescription());
            a.ad("WebSelectItem", WebSelectItemDescriptionMetadata.a);
        }
    }
    WebSelectItemDescriptionMetadata.$t = /*@__PURE__*/ markType(WebSelectItemDescriptionMetadata, 'WebSelectItemDescriptionMetadata');
    WebSelectItemDescriptionMetadata.a = null;
    return WebSelectItemDescriptionMetadata;
})();
